@@ -28,17 +28,22 @@ class ImageRepository:
 
 @attr.s
 class Project:
-    environments: typing.List[Environment] = attr.ib(
-        converter=convert_identified_list_to_dict
-    )
-    image_repositories: typing.List[ImageRepository] = attr.ib(
-        converter=convert_identified_list_to_dict
-    )
     name = attr.ib()
     role_arn = attr.ib()
 
+    environments: typing.List[Environment] = attr.ib(
+        factory=list, converter=convert_identified_list_to_dict
+    )
+    image_repositories: typing.List[ImageRepository] = attr.ib(
+        factory=list, converter=convert_identified_list_to_dict
+    )
+
     aws_region_name = attr.ib(default="eu-west-1")
 
+    @property
+    def region_name(self):
+        return self.aws_region_name
+
 
 class ProjectList:
     @classmethod
